from setuptools import setup

setup(
    name='Cezar-first-hello',
    version='0.1.0',
    author='Horoiu Cezar',
    author_email='horoiucezar@yahoo.com',
    packages=['my_own_package'],
    package_dir={'':'src\\'},
    include_package_data=True

)